@@ -212,7 +212,7 @@ gboolean mh_scan_required(Folder *folder, FolderItem *item)
 	path = folder_item_get_path(item);
 	g_return_val_if_fail(path != NULL, FALSE);
 
-	if (stat(path, &s) < 0) {
+	if (g_stat(path, &s) < 0) {
 		FILE_OP_ERROR(path, "stat");
 		g_free(path);
 		return FALSE;
@@ -626,7 +626,7 @@ static gint mh_remove_msg(Folder *folder, FolderItem *item, gint num)
 	need_scan = mh_scan_required(folder, item);
 	last_mtime = item->mtime;
 
-	if (g_unlink(file) < 0) {
+	if (claws_unlink(file) < 0) {
 		FILE_OP_ERROR(file, "unlink");
 		g_free(file);
 		return -1;
@@ -679,7 +679,7 @@ static gint mh_remove_msgs(Folder *folder, FolderItem *item,
 		if (file == NULL)
 			continue;
 		
-		if (g_unlink(file) < 0) {
+		if (claws_unlink(file) < 0) {
 			g_free(file);
 			continue;
 		}
@@ -1453,7 +1453,7 @@ static void mh_set_mtime(Folder *folder, FolderItem *item)
 
 	g_return_if_fail(path != NULL);
 
-	if (stat(path, &s) < 0) {
+	if (g_stat(path, &s) < 0) {
 		FILE_OP_ERROR(path, "stat");
 		g_free(path);
 		return;
